*****************************************************************************************
*This file creates offender level data.  It counts the total number of offenders per
*day.  Though type A offenses are taken from the offender file, Type B offenses are taken
*from the arrest file.  There is no Type B offender file.  If one incident is associated
*with multiple offenses--e.g. shoplifting and vehicle theft, each offense is counted
*separately for each offender.  
*****************************************************************************************

/*
 Window Arrest Segment (W6):
 Contains information on arrests 
 for which there is no other information in that year.  This happens when an ORI 
 doesn't do complete NIBRS record.  Might do this when the incident is more than 
 1 year prior to the arrest.  Other instances when they don't send a complete NIBRS record are
 human error and other random things.  It turns out that the FBI did not put incident date
 information in this segment - the field W6005 is always, or nearly always, missing.  Hence,
 this is completely useless for us.
 
*/ 
 
# delimit ;

capture log close;
capture macro drop _all;
capture program drop _all;
set mem 430m;
set matsize 700;
set more off;

*Set macros depending on which machine the program is running;
 
global dweath "c:\projects\crime\data\weather";
global dsch "c:\projects\crime\data\schoolcalendars";
global dcrime "c:\projects\crime\school\revised";
global dnibrs "c:\projects\crime\data\nibrs";

/*
 global dsch "d:\sch_crime\data";
 global dcrime "d:\sch_crime\data";
 global dnibrs "d:\nibrsdata";
*/

 cd ${dcrime};
 log using sch_nibrs.log, replace;


************************;
*** Group A Offenses ***;
************************;

program define groupa;

****************************************************************************************;
*Read in administrative data file which contains incident information.  Not all of the
*oris listed have school data so I'm going to create a list that contains only those
*oris that we have calendar data for.  This will speed up the program.;
****************************************************************************************;


use V1003 V1004 V1005 V1006 V1007 if 
    V1003=="ID0100200" | V1003=="UT0060300" |
    V1003=="UT0030100" | V1003=="ID0140200" |
    V1003=="ID0420200" | V1003=="UT0180500" |
    V1003=="UT0182500" | V1003=="SC0230200" |
    V1003=="CO0010500" | V1003=="IA0070300" |
    V1003=="CO0010100" | V1003=="CO0210100" |
    V1003=="CO0300400" | V1003=="ID0010100" |
    V1003=="IA0570100" | V1003=="IA0770300" |
    V1003=="IA0820200" | V1003=="MA0071800" |
    V1003=="MA0146000" | V1003=="OH0570200" |
    V1003=="OH0770100" | V1003=="OHCIP0000" |
    V1003=="SC0400100" | V1003=="TX2270100" |
    V1003=="UT0250600" | V1003=="VA1160000" |
    V1003=="IA0520200" | V1003=="ND0510200" |
    V1003=="ND0090200"
using ${dnibrs}\nibrs`1'_adm.dta;


 rename V1003 ori;
 rename V1004 incnum;
 rename V1005 incdate;
 rename V1006 repdate;
 rename V1007 ihour;
 
 
 gen year=real(substr(incdate,1,4));
   label variable year "year of incident";
 gen month=real(substr(incdate,5,2));
   label variable month "month of incident";
 gen day=real(substr(incdate,7,2));
   label variable day "day of incident";
 gen idate=mdy(month,day,year);
 
*Merge on city indicator from batch 1 files;

 mmerge ori using "${dnibrs}\nibrs`1'_bh1.dta", type(n:n) unmatched(master) umatch(B1003)
    ukeep(B1012) urename(B1012 oritype);

 tab oritype, missing;
	***Note: we are indeed getting only cities;
	

*Merge on incident data from offense (aka incident) files - Segment 2;
*Note that there are often multiple offense records associated with one incident record;

 mmerge ori incnum using "${dnibrs}\nibrs`1'_inc.dta", type(1:n) umatch(V2003 V2004)
 unmatched(master) ukeep(V2006 V2011) urename (V2006 ucrcode \ V2011 venue);

********************************************************************************;
*About 10-20% of incidents have dates that correspond to reporting and not occurence;
*We will only examine incidents that occured on the incident date--not incidents
*that were reported on the incident date so we drop the other observations;
********************************************************************************;
 
tab repdate, missing;
keep if repdate=="";
drop _merge repdate;
drop if ori=="";

*********************************************************************************;
*We will now merge on offender data.
*********************************************************************************;

mmerge ori incnum using ${dnibrs}\nibrs`1'_off.dta, type(n:n) umatch(V5003 V5004)
    unmatched(master) ukeep (V5006 V5007 V5008 V5009)
    urename (V5006 seqnum \ V5007 iage \ V5009 race \ V5008 gender);

 keep if seqnum~=.;
 gen noage=iage==0 if iage!=.;
 tab noage, missing;
 replace iage=. if iage==0;
 gen juv=iage>=5 & iage<18 if iage~=.;
 gen adlt=iage>=18 if iage~=.; 
 drop noage;
 
 compress;
 doub2flt _all;
 desc;
 keep ori seqnum year month day idate ihour iage incnum ucrcode juv adlt venue race
   gender;
 
 save ${dcrime}\groupa`1'.dta, replace;
 clear;
 
 end;
 
 **;

/*
 groupa 95 1995;
 groupa 96 1996;
 groupa 97 1997;
 groupa 98 1998;
 groupa 99 1999;
*/

*************************;
*** Group B Offenses ****;
*************************;

*NIBRS contains no additional information (in any of the segments) about Group B Offenses.  These are 
 offenses that are not reported, but that police simply detect and arrest on the spot.  If there is an
 incident report for a more serious Group A offense and, when the police make an arrest, they find that 
 the offender has committed Group B offenses as well, these are not marked down.  The Group A offenses, 
 as the more serious, override the Group B offenses;

*These offenses have no information on incident HOUR;

program define groupb;

*Read in the groupb arrest information;


use V7003 V7004 V7005 V7006 V7009 V7012 V7013 V7014 if 
    V7003=="ID0100200" | V7003=="UT0060300" |
    V7003=="UT0030100" | V7003=="ID0140200" |
    V7003=="ID0420200" | V7003=="UT0180500" |
    V7003=="UT0182500" | V7003=="SC0230200" |
    V7003=="CO0010500" | V7003=="IA0070300" |
    V7003=="CO0010100" | V7003=="CO0210100" |
    V7003=="CO0300400" | V7003=="ID0010100" |
    V7003=="IA0570100" | V7003=="IA0770300" |
    V7003=="IA0820200" | V7003=="MA0071800" |
    V7003=="MA0146000" | V7003=="OH0570200" |
    V7003=="OH0770100" | V7003=="OHCIP0000" |
    V7003=="SC0400100" | V7003=="TX2270100" |
    V7003=="UT0250600" | V7003=="VA1160000" |
    V7003=="IA0520200" | V7003=="ND0510200" |
    V7003=="ND0090200"

using ${dnibrs}\nibrs`1'_arb.dta;



 rename V7003 ori;
 rename V7004 incnum;
 rename V7005 incdate;
 rename V7006 seqnum;
 rename V7009 ucrcode;
 rename V7012 iage;
 rename V7013 gender;
 rename V7014 race;
 
 replace iage=. if iage==0;
 gen juv=iage>=5 & iage<18 & iage~=.;
 gen adlt=iage>=18 & iage~=.;

 gen year=real(substr(incdate,1,4));
   label variable year "year of incident";
 gen month=real(substr(incdate,5,2));
   label variable month "month of incident";
 gen day=real(substr(incdate,7,2));
   label variable day "day of incident";
 gen idate=mdy(month,day,year);
 
 compress;
 doub2flt _all;
 desc;
 keep ori seqnum year month day idate incnum ucrcode iage juv adlt gender race;


 save ${dcrime}\groupb`1'.dta, replace;
 clear;
end;

/*
 groupb 95 ;
 groupb 96 ;
 groupb 97 ;
 groupb 98 ;
 groupb 99 ;
*/


***************************;
*** All Offenses       ****;
***************************;

*Now we append the files from all years together. One incident may be listed in two years if 
 an arrest was made in the year following the incident.  The record from the year of the arrest 
 will have all relevant information, including the correct incident date, so simply take this 
 record.  This essentially involves taking the record with the most recent year;


 use ${dcrime}\groupa95.dta;
 for num 96/99: append using groupaX.dta;

 egen tmp=nvals(year), by(ori incnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;
 

 for num 95/99: append using groupbX.dta;



    
*** Label Offense Codes ***;

  gen str30 ucrname="";
  label var ucrname "UCR Offense Name";
  replace ucrname="Arson"					if ucrcode=="200";
  replace ucrname="Aggravated Assault"				if ucrcode=="13A";
  replace ucrname="Simple Assault"				if ucrcode=="13B";
  replace ucrname="Intimidation" 				if ucrcode=="13C";
  replace ucrname="Bribery"					if ucrcode=="510";
  replace ucrname="Burglary"					if ucrcode=="220";
  replace ucrname="Counterfeiting/Forgery" 			if ucrcode=="250";
  replace ucrname="Vandalism"				        if ucrcode=="290";
  replace ucrname="Drug/Narcotic Violations"			if ucrcode=="35A";
  replace ucrname="Drug Equipment Violations"			if ucrcode=="35B";
  replace ucrname="Embezzlement"				if ucrcode=="270";
  replace ucrname="Extortion/Blackmail" 			if ucrcode=="210";
  replace ucrname="False Pretenses/Swindle"			if ucrcode=="26A";
  replace ucrname="Credit Card/ATM Fraud"			if ucrcode=="26B";
  replace ucrname="Impersonation"				if ucrcode=="26C";
  replace ucrname="Welfare Fraud"				if ucrcode=="26D";
  replace ucrname="Wire Fraud"					if ucrcode=="26E";
  replace ucrname="Betting/Wagering"				if ucrcode=="39A";
  replace ucrname="Operating/Promote Gambling"			if ucrcode=="39B";
  replace ucrname="Gambling Equipment Violations"		if ucrcode=="39C";
  replace ucrname="Sports Tampering"				if ucrcode=="39D";
  replace ucrname="Murder/Nonnegligent Manslaughter"		if ucrcode=="09A";
  replace ucrname="Negligent Manslaughter"			if ucrcode=="09B";
  replace ucrname="Justifiable Homicide"			if ucrcode=="09C";
  replace ucrname="Kidnaping/Abduction"  			if ucrcode=="100";
  replace ucrname="Pocket-picking" 				if ucrcode=="23A";
  replace ucrname="Purse-snatching"				if ucrcode=="23B";
  replace ucrname="Shoplifting"				  	if ucrcode=="23C";
  replace ucrname="Theft From Building"		  		if ucrcode=="23D";
  replace ucrname="Theft From Coin-Operated Machine"		if ucrcode=="23E";
  replace ucrname="Theft From Motor Vehicle"			if ucrcode=="23F";
  replace ucrname="Motor Vehicle Theft - Parts"			if ucrcode=="23G";
  replace ucrname="All Other Larceny"				if ucrcode=="23H";
  replace ucrname="Motor Vehicle Theft"				if ucrcode=="240";
  replace ucrname="Pornography/Obscene Material"		if ucrcode=="370";
  replace ucrname="Prostitution"				if ucrcode=="40A";
  replace ucrname="Assist/Promote Prostitution"			if ucrcode=="40B";
  replace ucrname="Robbery"					if ucrcode=="120";
  replace ucrname="Forcible Rape"				if ucrcode=="11A";
  replace ucrname="Forcible Sodomy"				if ucrcode=="11B";
  replace ucrname="Sexual Assault With An Object"		if ucrcode=="11C";
  replace ucrname="Child Molestation"				if ucrcode=="11D";
  replace ucrname="Incest"					if ucrcode=="36A";
  replace ucrname="Statutory Rape"				if ucrcode=="36B";
  replace ucrname="Stolen Property Offense"			if ucrcode=="280";
  replace ucrname="Weapon Law Violations"			if ucrcode=="520";

compress;
doub2flt _all;

*for num 95/99: ! del "${dcrime}\groupaX.dta";
*for num 95/99: ! del "${dcrime}\groupbX.dta";


capture drop schr othr;
gen schr=ihour>6 & ihour<=14;
gen othr=schr==0 & ihour~=.;

gen emrn=ihour<=5;
gen mrn=ihour>5 & ihour<=11;
gen aft=ihour>11 & ihour<=16;
gen evn=ihour>16 & ihour<=20;
gen nt=1-emrn-mrn-aft-evn & ihour~=.;


*** Create Offender Data ***;

 gen byte viol=ucrcode=="13A" | ucrcode=="13B" | ucrcode=="13C" | ucrcode=="09A" | ucrcode=="09B"
    | ucrcode=="09C" | ucrcode=="100" | ucrcode=="11A" | ucrcode=="11B" | ucrcode=="11C" 
    | ucrcode=="11D" | ucrcode=="36A" | ucrcode=="36B";

 gen byte prop=ucrcode=="510" | ucrcode=="220" | ucrcode=="250" | ucrcode=="290" | ucrcode=="210" 
    | ucrcode=="270" | ucrcode=="26A" | ucrcode=="26B" | ucrcode=="26C"
    | ucrcode=="26D" | ucrcode=="26E" | ucrcode=="23A" | ucrcode=="23B" | ucrcode=="23C"
    | ucrcode=="23D" | ucrcode=="23E" | ucrcode=="23F" | ucrcode=="23G" | ucrcode=="23H"
    | ucrcode=="240" | ucrcode=="120" | ucrcode=="280";

  gen byte serious=ucrcode=="09A" | ucrcode=="09B" | ucrcode=="09C"; **homicide;
  gen byte shpl=ucrcode=="23C";
  gen byte aslt=ucrcode=="13B";
  gen byte aggaslt=ucrcode=="13A";
  gen byte drug=ucrcode=="35A" | ucrcode=="35B";
  
  gen byte veht=ucrcode=="240";
  gen byte vand=ucrcode=="290";
  gen byte robb=ucrcode=="120";
  gen byte burg=ucrcode=="220";
  gen byte weap=ucrcode=="520";
  gen byte dscn=ucrcode=="90C";
  gen byte loit=ucrcode=="90B";
       
  gen byte groupb=ucrcode=="90A" |ucrcode=="90B" |ucrcode=="90C" |ucrcode=="90D" |ucrcode=="90E"
    |ucrcode=="90F" |ucrcode=="90G" |ucrcode=="90H" |ucrcode=="90I" |ucrcode=="90J" |ucrcode=="90Z" ;

  gen byte crimea=1-groupb;

  gen byte otha=crimea-viol-prop;

*********************************;
*The next lines generate variables by offender age and then time of day in which it was committed.
*********************************;


  for any viol prop shpl aslt drug veht vand robb burg groupb crimea
     otha weap dscn loit aggaslt serious:
     gen byte j_X=juv*X \
     gen byte a_X=adlt*X ;



  for any viol prop crimea otha: gen byte j_sh_X=j_X*schr \ gen byte a_sh_X=a_X*schr
    \ gen byte j_oh_X=j_X*othr \ gen byte a_oh_X=a_X*othr \ gen byte j_emrn_X=j_X*emrn
    \ gen byte a_emrn_X=a_X*emrn \ gen byte j_mrn_X=j_X*mrn \ gen byte a_mrn_X=a_X*mrn 
    \ gen byte j_aft_X=j_X*aft \ gen byte a_aft_X=a_X*aft \ gen byte j_evn_X=j_X*evn
    \ gen byte a_evn_X=a_X*evn \ gen byte j_nt_X=j_X*nt \ gen byte a_nt_X=a_X*nt \; 

  
  *It is actually too large to collapse easily in one file, so I now break it back into 
   separate year files, which I will have to merge back together;
   

  save ${dcrime}\temp2.dta, replace;
  use ${dcrime}\temp2.dta, replace;

  vallist ori, global(marker);


  for any ${marker}: 
   	use "${dcrime}\temp2.dta" if ori=="X" \
   	collapse (sum) juv adlt j_* a_* , by(ori year month day) \
   	save oX.dta, replace \
   	clear;



   set obs 1;
   gen byte mark=1;
   save tmp.dta, replace;
   for any ${marker}: append using "${dcrime}\oX.dta";
   drop if ori=="";
   drop mark;


*  for any ${marker}: ! del "${dcrime}\oX.dta";
*  ! del temp2.dta;

*** Label Cities ***;

    gen str20 city="";
    
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

    label variable city "city";


  gen date = mdy(month, day, year);
  format date %d;
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var juv adlt j_* a_*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";

*Create other variables;

 for any sun tue wed thu fri sat \ any 0 2 3 4 5 6: gen byte dd_X=dow(date)==Y;

 egen cmy=group(city month year);

 for num 1996/1999: gen byte yyX=year==X;

*Merge on population information;

 mmerge ori year using "${dnibrs}\pop9599.dta", type(n:1) unmatched(master) ukeep(ori year pop);
 sum pop, det;
 drop _merge;


******************************************************************************
*Merge on Calendar Information.
******************************************************************************;

 mmerge city year month day using "${dsch}\finalcalendars.dta", type(n:1)
    umatch(city year month day);

 
 **********************;
 ***Create Variables***;
 **********************;

*I get rid of the observations occuring before the first school day.;

 gen flag=firstday*date;
 egen startsamp=min(flag), by(city);
 gen startmn=month(startsamp);
 gen startyr=year(startsamp);
 drop if year<startyr | (year==startyr & month<startmn);

 drop flag startsamp startmn startyr;

*Create indicator for the summers of 1996, 1997, 1998, 1999, 2000 and 2001;

 gen fday9495=mdy(month,day,year) if firstday==1&year==1994; 
 gen lday9495=mdy(month,day,year) if lastday==1&year==1995;

 gen fday9596=mdy(month,day,year) if firstday==1&year==1995; 
 gen lday9596=mdy(month,day,year) if lastday==1&year==1996;
 
 gen fday9697=mdy(month,day,year) if firstday==1&year==1996; 
 gen lday9697=mdy(month,day,year) if lastday==1&year==1997;
 
 gen fday9798=mdy(month,day,year) if firstday==1&year==1997; 
 gen lday9798=mdy(month,day,year) if lastday==1&year==1998;
 
 gen fday9899=mdy(month,day,year) if firstday==1&year==1998; 
 gen lday9899=mdy(month,day,year) if lastday==1&year==1999;
 
 gen fday9900=mdy(month,day,year) if firstday==1&year==1999; 
 gen lday9900=mdy(month,day,year) if lastday==1&year==2000;
 
 gen fday0001=mdy(month,day,year) if firstday==1&year==2000; 
 gen lday0001=mdy(month,day,year) if lastday==1&year==2001;
 
 gen fday0102=mdy(month,day,year) if firstday==1&year==2001; 
 gen lday0102=mdy(month,day,year) if lastday==1&year==2002;


 for any 9495 9596 9697 9798 9899 9900 0001 0102: 
 	egen fdtX=max(fdayX), by(city) \ egen ldtX=max(ldayX), by(city);

 
 gen summer=(date>ldt9495&date<fdt9596) | (date<fdt9596 & ldt9495==.) if fdt9596~=.; 
 replace summer=0 if (date>=fdt9596 & date<=ldt9596) & ldt9596~=.;
 replace summer=1 if (date>ldt9596&date<fdt9697) | (date<fdt9697 & ldt9596==.) & fdt9697~=.; 
 replace summer=0 if (date>=fdt9697 & date<=ldt9697) & ldt9697~=.;
 replace summer=1 if (date>ldt9697&date<fdt9798) | (date<fdt9798 & ldt9697==.) & fdt9798~=.; 
 replace summer=0 if (date>=fdt9798 & date<=ldt9798) & ldt9798~=.;
 replace summer=1 if (date>ldt9798&date<fdt9899) | (date<fdt9899 & ldt9798==.) & fdt9899~=.; 
 replace summer=0 if (date>=fdt9899 & date<=ldt9899) & ldt9899~=.;
 replace summer=1 if (date>ldt9899&date<fdt9900) | (date<fdt9900 & ldt9899==.) & fdt9900~=.; 
 replace summer=0 if (date>=fdt9900 & date<=ldt9900) & ldt9900~=.;
 replace summer=1 if (date>ldt9900&date<fdt0001) | (date<fdt0001 & ldt9900==.) & fdt0001~=.; 
 replace summer=0 if (date>=fdt0001 & date<=ldt0001) & ldt0001~=.;
 capture replace summer=1 if (date>ldt00001&date<fdt0102) | (date<fdt0102 & ldt0001==.) & fdt0102~=.; 
 capture replace summer=0 if (date>=fdt0102 & date<=ldt0102) & ldt0102~=.;


     ***summer variables will be missing when we do not have school calendar info;
  

 for any holiday inservice break: replace X=0 if X==.;
 
 gen nosch=inservice==1|holiday==1|break==1|summer==1;
 

  drop if city=="Akron, OH" & year<1999;
  drop if city=="Anderson, SC" & year==1995 & (month==11|month==12);
  drop if city=="Aurora, CO" & year<1997;
  drop if city=="Austin, TX" & year<1998;
  drop if city=="Beaufort, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Boise, ID" & year<1995 ;
  drop if city=="Cedar Rapids, IA" & year<1999;
  drop if city=="Charleston, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Cincinnati, OH" & year<1998;
  drop if city=="Clarksville, TN" & year<1998;
  drop if city=="Colorado Springs, CO" & year<1997;
  drop if city=="Columbia, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Council Bluffs, IA" & year<1998;
  drop if city=="Davenport, IA" & year==1996 & month==7;
  drop if city=="Dayton, OH" & year<1998;
  drop if city=="Des Moines, IA" & year<1995;
  drop if city=="Florence, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Greenville, SC" & year<1995;
  drop if city=="Jackson, MI" & year<1997;
  drop if city=="Lakewood, CO" & year<1997;
  drop if city=="Myrtle Beach, SC" & year==1995 & (month==11|month==12);
  drop if city=="Newport News, VA" & (year<1998 | (year==1998 & month<7));
  drop if city=="Orangeburg, SC" & year==1995 & (month==11|month==12);
  drop if city=="Petersburg, VA" & ((year==1995 & month<10)|(year==1999 & month==6));
  drop if city=="Provo, UT" & year<1995;
  drop if city=="Sandy, UT" & year<1995;
  drop if city=="Sioux City, IA" & year<1995;
  drop if city=="Southfield, MI" & (year<1996 | (year==1996 & month<5)); 
  drop if city=="Spartanburg, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Springfield, MA" & (year<1996 | (year==1996 & month<6));
  drop if city=="Sterling Heights, MI" & year==1995 & month<3;
  drop if city=="Waterloo, IA" & ((year==1996 & month<8) | year<1996);
  drop if city=="West Valley, UT" & ((year==1998 & month<8) | year<1998);
  drop if city=="Westminster, CO" & ((year==1999 & month==1) | (year==1998 & month==12)
     | (year==1997 & month>3) | year<1997);
  drop if city=="Worcester, MA" & year<1995;
  drop if city=="Idaho Falls, ID" & year<1995;
  drop if city=="Nampa, ID" & year<1995;
  drop if city=="Twin Falls, ID" & year<1995;
  drop if city=="Layton, UT" & ((year==1999 & month>=3 & month<=5) | (year==1998 & month>=7)
     | (year==1996 & month==9) | (year==1995 & month>=7 & month<=8) | (year==1995 & month<9)
     | year<1995);
  drop if city=="Logan, UT" & ((year==1999 & month==12) | (year==1998 & month>=11) | year<1995);
  drop if city=="Nampa, ID" & (year==1995 & (month==11 | month==12));
  drop if city=="Iowa City, IA" & (year<1996 | (year==1996 & month<8)); **Calendar data missing 1995/1996;
  drop if city=="Minot, ND" & (year==1995 & (month==11 | month==12));
  drop if city=="Fargo, ND" & year<1995;
  drop if summer==.;

*I will keep only those observations with offender data;
 keep if juv~=.;
 
 
 drop fdt* ldt* fday* lday* _merge;
 
 sum;
 desc;
 compress;
 doub2flt _all;
 
save ${dcrime}\school_offenders.dta, replace;

log close;

**;

