**********************************************************************************
*This file will read in juvenile victimization data by day and city.  It may
*also be worth looking at time of day.  I will first examine who is victimized
*by juveniles.  This will allow us to examine who benefits (or suffers) from
*school induced crime reductions (increases).  I will then focus on overall
*victimization rates of juveniles and adults.  It might even be worth examining
*victimization rates of older children to get a more focused view.
**********************************************************************************;

# delimit ;

capture log close;
capture macro drop _all;
capture program drop _all;
set mem 400m;
set matsize 700;
set more off;

*Set macros depending on which machine the program is running;
 
global dweath "c:\projects\crime\data\weather";
global dsch "c:\projects\crime\data\schoolcalendars";
global dcrime "c:\projects\crime\school\revised";
global dnibrs "c:\projects\crime\data\nibrs";

/*
 global dsch "d:\sch_crime\data";
 global dcrime "d:\sch_crime\data";
 global dnibrs "d:\nibrsdata";
*/ 
 cd ${dcrime};
 log using victim_school.log, replace;

*Set global to indicate machine (Brian=1, Lars=0);
 global n=1;


program define sch_vic;

*****************************************************************************;
*I first read in administrative information so I can find out the time of the incident
*along with the date and other information.;
*****************************************************************************;


use V1003 V1004 V1005 V1006 V1007 if 
    V1003=="ID0100200" | V1003=="UT0060300" |
    V1003=="UT0030100" | V1003=="ID0140200" |
    V1003=="ID0420200" | V1003=="UT0180500" |
    V1003=="UT0182500" | V1003=="SC0230200" |
    V1003=="CO0010500" | V1003=="IA0070300" |
    V1003=="CO0010100" | V1003=="CO0210100" |
    V1003=="CO0300400" | V1003=="ID0010100" |
    V1003=="IA0570100" | V1003=="IA0770300" |
    V1003=="IA0820200" | V1003=="MA0071800" |
    V1003=="MA0146000" | V1003=="OH0570200" |
    V1003=="OH0770100" | V1003=="OHCIP0000" |
    V1003=="SC0400100" | V1003=="TX2270100" |
    V1003=="UT0250600" | V1003=="VA1160000" |
    V1003=="IA0520200" | V1003=="ND0510200" |
    V1003=="ND0090200"
 using ${dnibrs}\nibrs`1'_adm.dta;


 rename V1003 ori;
 rename V1004 incnum;
 rename V1005 incdate;
 rename V1006 repdate;
 rename V1007 ihour;
 

 gen year=real(substr(incdate,1,4));
   label variable year "year of incident";
 gen month=real(substr(incdate,5,2));
   label variable month "month of incident";
 gen day=real(substr(incdate,7,2));
   label variable day "day of incident";
 gen idate=mdy(month,day,year);

 keep if repdate=="";
 drop if ori=="";
  
*******************************************************************************;
*Merge on victim data.  I use the UCR code from the victim report to assign
*violent and property crime status.;
*******************************************************************************;

mmerge ori incnum using ${dnibrs}\nibrs`1'_vic.dta, type(n:n) umatch(V4003 V4004) 
   unmatched(master) ukeep (V4006 V4007 V4008 V4009 V4010 V4011 V4012 V4013 V4014 V4015
   V4016 V4017 V4018 V4019 V4020)
   urename (V4017 victype \ V4018 vage \ V4006 vicnum \ V4019 gender \ V4020 race);

*I want to make sure that I only keep crimes with victims.  The next line assures
*that this is the case;

 keep if victype~="";

 gen juv=victype=="I" & real(vage)>=5 & real(vage)<18 ;
 gen adlt=victype=="I" & real(vage)>=18 & real(vage)~=.;
 gen inst=victype=="B" | victype=="F" | victype=="G" | victype=="S"
    | victype=="R" | victype=="O";

*The next lines create a variable that indicates whether the victim suffered
*from a violent crime or a property crime.  Multiple UCR codes are listed so
*it is possible that both occured.
*At most a single victim can have a value of 1 for both property and violent
*crime.;


 gen viol=0;
 for var V4007-V4016: replace viol=1 if X=="13A" | X=="13B" | X=="13C" | X=="09A" | X=="09B"
    | X=="09C" | X=="100" | X=="11A" | X=="11B" | X=="11C" | X=="11D" | X=="36A" | X=="36B";

 gen prop=0;
 for var V4007-V4016: replace prop=1 if X=="510" | X=="220" | X=="250" | X=="290"
    |X=="210" | X=="270" | X=="26A" | X=="26B" | X=="26C" | X=="26D" | X=="26E" | X=="23A"
    | X=="23B" | X=="23C" | X=="23D" | X=="23E" | X=="23F" | X=="23G" | X=="23H"
    | X=="240" | X=="120" | X=="280";


  keep ori incnum vicnum year month day idate juv adlt inst prop viol gender race vage;

  save tmp, replace;

*******************************************************************************************;
*I am now going to manipulate the offender data so there is one record per incident.
*I will create a measure that takes on a value of 1 if any of the offenders were
*juveniles.  This prevents us from double counting victimizations.
*******************************************************************************************;

use V5003 V5004 V5007 if 
    V5003=="ID0100200" | V5003=="UT0060300" |
    V5003=="UT0030100" | V5003=="ID0140200" |
    V5003=="ID0420200" | V5003=="UT0180500" |
    V5003=="UT0182500" | V5003=="SC0230200" |
    V5003=="CO0010500" | V5003=="IA0070300" |
    V5003=="CO0010100" | V5003=="CO0210100" |
    V5003=="CO0300400" | V5003=="ID0010100" |
    V5003=="IA0570100" | V5003=="IA0770300" |
    V5003=="IA0820200" | V5003=="MA0071800" |
    V5003=="MA0146000" | V5003=="OH0570200" |
    V5003=="OH0770100" | V5003=="OHCIP0000" |
    V5003=="SC0400100" | V5003=="TX2270100" |
    V5003=="UT0250600" | V5003=="VA1160000" |
    V5003=="IA0520200" | V5003=="ND0510200" |
    V5003=="ND0090200"
  using ${dnibrs}\nibrs`1'_off.dta;
  rename V5003 ori;
  rename V5004 incnum;
  rename V5007 oage;
  gen juvoff=oage>=5 & oage<18;
  collapse (max) juvoff, by(ori incnum);
  
mmerge ori incnum using  ${dcrime}\tmp.dta, type(n:n) umatch(ori incnum) 
   unmatched(master);

*I only keep the observations with data on the victims;

  keep if juv~=.;
  drop _merge;

  save sch_vic`1', replace;
  ! del tmp.dta ;
 
end;

  sch_vic 95;
  sch_vic 96;
  sch_vic 97;
  sch_vic 98;
  sch_vic 99;

  clear;
  use sch_vic95;
  for num 96/99: append using sch_vicX;


*Rarely the information is recorded in multiple years.  The next lines take care of this.;

 egen tmp=nvals(year), by(ori incnum vicnum);
 tab tmp, m;
 drop tmp;
 egen tmp=max(year), by(ori incnum);
 gen mark=year==tmp;
 tab mark, m;
 keep if mark==1;
 drop mark tmp;
   
 gen totvic=1;
 gen juv_juv=juv==1&juvoff==1;
 gen juv_adlt=adlt==1&juvoff==1;
 gen juv_inst=inst==1&juvoff==1;

 gen juv_v=juv==1 & viol==1;
 gen juv_p=juv==1 & prop==1;
 gen adlt_v=adlt==1 & viol==1;
 gen adlt_p=adlt==1 & prop==1;


 gen juv_juv_v=juv_juv==1 & viol==1;
 gen juv_juv_p=juv_juv==1 & prop==1;
 gen juv_adlt_v=juv_adlt==1 & viol==1;
 gen juv_adlt_p=juv_adlt==1 & prop==1;

 collapse (sum) totvic viol prop juv* adlt* inst*, by(ori year month day);

*** Label Cities ***;

    gen str20 city="";
    
    replace city="Aurora, CO" if ori=="CO0010100";
    replace city="Colorado Springs, CO" if ori=="CO0210100";
    replace city="Lakewood, CO" if ori=="CO0300400";
    replace city="Boise, ID" if ori=="ID0010100";
    replace city="Cedar Rapids, IA" if ori=="IA0570100";
    replace city="Des Moines, IA" if ori=="IA0770300";
    replace city="Davenport, IA" if ori=="IA0820200";
    replace city="Springfield, MA" if ori=="MA0071800";
    replace city="Worcester, MA" if ori=="MA0146000";
    replace city="Dayton, OH" if ori=="OH0570200";
    replace city="Akron, OH" if ori=="OH0770100";
    replace city="Cincinnati, OH" if ori=="OHCIP0000";
    replace city="Columbia, SC" if ori=="SC0400100";
    replace city="Austin, TX" if ori=="TX2270100";
    replace city="Provo, UT" if ori=="UT0250600";
    replace city="Newport News, VA" if ori=="VA1160000";
    replace city="Sandy, UT" if ori=="UT0180500";
    replace city="West Valley, UT" if ori=="UT0182500";
    replace city="Greenville, SC" if ori=="SC0230200";
    replace city="Westminster, CO" if ori=="CO0010500";
    replace city="Waterloo, IA" if ori=="IA0070300";
    replace city="Idaho Falls, ID" if ori=="ID0100200"; 
    replace city="Layton, UT" if ori=="UT0060300"; 
    replace city="Logan, UT" if ori=="UT0030100"; 
    replace city="Nampa, ID" if ori=="ID0140200"; 
    replace city="Twin Falls, ID" if ori=="ID0420200"; 
    replace city="Iowa City, IA" if ori=="IA0520200";
    replace city="Minot, ND" if ori=="ND0510200";
    replace city="Fargo, ND" if ori=="ND0090200";

    label variable city "city";

  gen date = mdy(month, day, year);
  format date %d;
  egen c=group(city);

*Some small cities may have no crime reported on a given day.  The next line ensure that these
*zero crime days are reported as zeros instead of missing values.  I then eliminate the months
*with missing data in the subsequent section.;

  tsset c date;
  tsfill;
  for var totvic viol prop juv* adlt* inst*: replace X=0 if X==.;
  replace year=year(date) if year==.;
  replace month=month(date) if month==.;
  replace day=day(date) if day==.;
  for num 1/10: replace city=city[_n-X] if c==c[_n-X] & city=="" 
    \ replace city=city[_n+X] if c==c[_n+X] & city=="";


*Create other variables;

 for any sun tue wed thu fri sat \ any 0 2 3 4 5 6: gen byte dd_X=dow(date)==Y;
 
 egen cmy=group(city month year);

 for num 1996/1999: gen byte yyX=year==X;

*Merge on population information;

 mmerge ori year using "${dnibrs}\pop9599.dta", type(n:1) unmatched(master) ukeep(ori year pop);
 sum pop, det;
 drop _merge;


******************************************************************************
*Merge on Calendar Information.
******************************************************************************;

 mmerge city year month day using "${dsch}\finalcalendars.dta", type(n:1)
    umatch(city year month day);

 
 **********************;
 ***Create Variables***;
 **********************;

*I get rid of the observations occuring before the first school day.;

 gen flag=firstday*date;
 egen startsamp=min(flag), by(city);
 gen startmn=month(startsamp);
 gen startyr=year(startsamp);
 drop if year<startyr | (year==startyr & month<startmn);

 drop flag startsamp startmn startyr;

*Create indicator for the summers of 1996, 1997, 1998, 1999, 2000 and 2001;

 gen fday9495=mdy(month,day,year) if firstday==1&year==1994; 
 gen lday9495=mdy(month,day,year) if lastday==1&year==1995;

 gen fday9596=mdy(month,day,year) if firstday==1&year==1995; 
 gen lday9596=mdy(month,day,year) if lastday==1&year==1996;
 
 gen fday9697=mdy(month,day,year) if firstday==1&year==1996; 
 gen lday9697=mdy(month,day,year) if lastday==1&year==1997;
 
 gen fday9798=mdy(month,day,year) if firstday==1&year==1997; 
 gen lday9798=mdy(month,day,year) if lastday==1&year==1998;
 
 gen fday9899=mdy(month,day,year) if firstday==1&year==1998; 
 gen lday9899=mdy(month,day,year) if lastday==1&year==1999;
 
 gen fday9900=mdy(month,day,year) if firstday==1&year==1999; 
 gen lday9900=mdy(month,day,year) if lastday==1&year==2000;
 
 gen fday0001=mdy(month,day,year) if firstday==1&year==2000; 
 gen lday0001=mdy(month,day,year) if lastday==1&year==2001;
 
 gen fday0102=mdy(month,day,year) if firstday==1&year==2001; 
 gen lday0102=mdy(month,day,year) if lastday==1&year==2002;


 for any 9495 9596 9697 9798 9899 9900 0001 0102: 
 	egen fdtX=max(fdayX), by(city) \ egen ldtX=max(ldayX), by(city);

 
 gen summer=(date>ldt9495&date<fdt9596) | (date<fdt9596 & ldt9495==.) if fdt9596~=.; 
 replace summer=0 if (date>=fdt9596 & date<=ldt9596) & ldt9596~=.;
 replace summer=1 if (date>ldt9596&date<fdt9697) | (date<fdt9697 & ldt9596==.) & fdt9697~=.; 
 replace summer=0 if (date>=fdt9697 & date<=ldt9697) & ldt9697~=.;
 replace summer=1 if (date>ldt9697&date<fdt9798) | (date<fdt9798 & ldt9697==.) & fdt9798~=.; 
 replace summer=0 if (date>=fdt9798 & date<=ldt9798) & ldt9798~=.;
 replace summer=1 if (date>ldt9798&date<fdt9899) | (date<fdt9899 & ldt9798==.) & fdt9899~=.; 
 replace summer=0 if (date>=fdt9899 & date<=ldt9899) & ldt9899~=.;
 replace summer=1 if (date>ldt9899&date<fdt9900) | (date<fdt9900 & ldt9899==.) & fdt9900~=.; 
 replace summer=0 if (date>=fdt9900 & date<=ldt9900) & ldt9900~=.;
 replace summer=1 if (date>ldt9900&date<fdt0001) | (date<fdt0001 & ldt9900==.) & fdt0001~=.; 
 replace summer=0 if (date>=fdt0001 & date<=ldt0001) & ldt0001~=.;
 capture replace summer=1 if (date>ldt00001&date<fdt0102) | (date<fdt0102 & ldt0001==.) & fdt0102~=.; 
 capture replace summer=0 if (date>=fdt0102 & date<=ldt0102) & ldt0102~=.;


     ***summer variables will be missing when we do not have school calendar info;
  

 for any holiday inservice break: replace X=0 if X==.;
 
 gen nosch=inservice==1|holiday==1|break==1|summer==1;
 

  drop if city=="Akron, OH" & year<1999;
  drop if city=="Anderson, SC" & year==1995 & (month==11|month==12);
  drop if city=="Aurora, CO" & year<1997;
  drop if city=="Austin, TX" & year<1998;
  drop if city=="Beaufort, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Boise, ID" & year<1995 ;
  drop if city=="Cedar Rapids, IA" & year<1999;
  drop if city=="Charleston, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Cincinnati, OH" & year<1998;
  drop if city=="Clarksville, TN" & year<1998;
  drop if city=="Colorado Springs, CO" & year<1997;
  drop if city=="Columbia, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Council Bluffs, IA" & year<1998;
  drop if city=="Davenport, IA" & year==1996 & month==7;
  drop if city=="Dayton, OH" & year<1998;
  drop if city=="Des Moines, IA" & year<1995;
  drop if city=="Florence, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Greenville, SC" & year<1995;
  drop if city=="Jackson, MI" & year<1997;
  drop if city=="Lakewood, CO" & year<1997;
  drop if city=="Myrtle Beach, SC" & year==1995 & (month==11|month==12);
  drop if city=="Newport News, VA" & (year<1998 | (year==1998 & month<7));
  drop if city=="Orangeburg, SC" & year==1995 & (month==11|month==12);
  drop if city=="Petersburg, VA" & ((year==1995 & month<10)|(year==1999 & month==6));
  drop if city=="Provo, UT" & year<1995;
  drop if city=="Sandy, UT" & year<1995;
  drop if city=="Sioux City, IA" & year<1995;
  drop if city=="Southfield, MI" & (year<1996 | (year==1996 & month<5)); 
  drop if city=="Spartanburg, SC" & year==1995 & (month==10|month==11|month==12);
  drop if city=="Springfield, MA" & (year<1996 | (year==1996 & month<6));
  drop if city=="Sterling Heights, MI" & year==1995 & month<3;
  drop if city=="Waterloo, IA" & ((year==1996 & month<8) | year<1996);
  drop if city=="West Valley, UT" & ((year==1998 & month<8) | year<1998);
  drop if city=="Westminster, CO" & ((year==1999 & month==1) | (year==1998 & month==12)
     | (year==1997 & month>3) | year<1997);
  drop if city=="Worcester, MA" & year<1995;
  drop if city=="Idaho Falls, ID" & year<1995;
  drop if city=="Nampa, ID" & year<1995;
  drop if city=="Twin Falls, ID" & year<1995;
  drop if city=="Layton, UT" & ((year==1999 & month>=3 & month<=5) | (year==1998 & month>=7)
     | (year==1996 & month==9) | (year==1995 & month>=7 & month<=8) | (year==1995 & month<9)
     | year<1995);
  drop if city=="Logan, UT" & ((year==1999 & month==12) | (year==1998 & month>=11) | year<1995);
  drop if city=="Nampa, ID" & (year==1995 & (month==11 | month==12));
  drop if city=="Iowa City, IA" & (year<1996 | (year==1996 & month<8)); **Calendar data missing 1995/1996;
  drop if city=="Minot, ND" & (year==1995 & (month==11 | month==12));
  drop if city=="Fargo, ND" & year<1995;
  drop if summer==.;

*I will keep only those observations with victimization data;
 keep if totvic~=.;
 
 
 drop fdt* ldt* fday* lday* _merge;
 
  compress;
  doub2flt _all;
  sum;
  desc;
  save "${dcrime}\school_victim.dta", replace;


log close ;

**;